@@ -4,7 +4,7 @@ import astropy.units as u
 import gwcs
 import pytest
 
-from dkist_fits_validator import spec214_validator
+from dkist_header_validator import spec214_validator
 from dkist_inventory.transforms import TransformBuilder
 from dkist_inventory.inventory import sort_headers, extract_inventory
 
